/* 
   LineData.java

   Title:      ParaProf
   Author:     Robert Bell
   
   A simple class used to gather line data from a file. Cheaper than a vector perhaps.

   Things to do: Class is complete.
*/

package edu.uoregon.tau.dms.dss;

final class LineData{
    public String s0 = null;
    public String s1 = null;
    public String s2 = null;
    public String s3 = null;

    public double d0 = 0.0;
    public double d1 = 0.0;
    public double d2 = 0.0;
    public double d3 = 0.0;
    public double d4 = 0.0;
    public double d5 = 0.0;

    public int i0 = 0;
    public int i1 = 0;
    public int i2 = 0;
    public int i3 = 0;
    public int i4 = 0;
    public int i5 = 0;
}
